def get_material_structure():
    print("Enter the material structure as a list of layer angles (e.g., [0, 30, 60, 0, 45]):")
    while True:
        try:
            input_str = input().strip()
            layer_angles = [int(angle) for angle in input_str[1:-1].split(',')]
            break
        except ValueError:
            print("Invalid input. Please try again.")
    return layer_angles

def get_unique_layers(layer_angles):
    unique_layers = list(set(layer_angles))
    return unique_layers

def input_layer_Q(unique_layers):
    layer_Q = {}
    for layer in unique_layers:
        print("Enter the Q matrix for layer angle " + str(layer) + " (6 values):")
        q11, q12, q13, q22, q23, q33 = [float(val) * 1e9 for val in input().split()]
        Q = [[q11, q12, q13], [q12, q22, q23], [q13, q23, q33]]
        layer_Q[layer] = Q
    return layer_Q

def calculate_A(layers, thicknesses):
    n = len(layers)
    A = [[0, 0, 0], [0, 0, 0], [0, 0, 0]]
    for k in range(n):
        Qk = layers[k]['Q']
        hk = thicknesses[k]
        for i in range(3):
            for j in range(3):
                A[i][j] += hk * Qk[i][j]
    return A

# Example usage
if __name__ == "__main__":
    layer_angles = get_material_structure()
    unique_layers = get_unique_layers(layer_angles)
    layer_Q = input_layer_Q(unique_layers)
    
    same_thickness = input("Are all layers of the same thickness? (y/n): ").lower().strip() == 'y'
    if same_thickness:
        thickness = float(input("Enter the thickness of all layers (in mm): ")) / 1000.0
        thicknesses = [thickness] * len(layer_angles)
    else:
        thicknesses = []
        for layer in layer_angles:
            thickness = float(input("Enter the thickness of layer " + str(layer) + " (in mm): ")) / 1000.0
            thicknesses.append(thickness)

    # Calculate h values based on the thicknesses (assuming the center is at 0)
    h_values = [-sum(thicknesses[:i+1])/2 for i in range(len(thicknesses))]
    h_values.append(sum(thicknesses)/2)

    layers = [{'thickness': h_values[i+1]-h_values[i], 'Q': layer_Q[layer_angles[i]]} for i in range(len(layer_angles))]
    
    result_A = calculate_A(layers, thicknesses)
    print("Matrix [A]:")
    for row in result_A:
        print(row)
